@@ -22,6 +22,7 @@ class BasePackageData:
     SERVICE_PREFIX: str = "mypy_boto3"
     SERVICE_PYPI_PREFIX: str = "mypy-boto3"
     LOCAL_DOC_LINK: str = "https://vemel.github.io/boto3_stubs_docs/"
+    IS_ASYNC = False
 
     @classmethod
     def get_service_package_name(cls, service_name: ServiceName) -> str:
@@ -81,6 +82,7 @@ class TypesAioBotocorePackageData(BasePackageData):
     SERVICE_PREFIX = "types_aiobotocore"
     SERVICE_PYPI_PREFIX = "types-aiobotocore"
     LOCAL_DOC_LINK = "https://vemel.github.io/types_aiobotocore_docs/"
+    IS_ASYNC = True
 
     @staticmethod
     def get_library_version() -> str:
